@@ -373,10 +373,12 @@ class MalwareDetectionClient:
                 # Remove extras slashes (/) in the file name and leading double slashes too (normpath doesn't)
                 item = os.path.normpath(item).replace('//', '/')
                 # Assume the item represents a filesystem item
-                if os.path.exists(item):
-                    self.scan_fsobjects.append(item)
-                else:
+                if not os.path.exists(item):
                     logger.info("Skipping missing filesystem_scan_only item: '%s'", item)
+                elif os.path.islink(item):
+                    logger.info("Skipping symlink filesystem_scan_only item: '%s'.  Please use non-symlink items", item)
+                else:
+                    self.scan_fsobjects.append(item)
 
             if self.scan_fsobjects:
                 logger.info("Scan only the specified filesystem item%s: %s", "s" if len(self.scan_fsobjects) > 1 else "",
@@ -402,12 +404,17 @@ class MalwareDetectionClient:
                 filesystem_scan_exclude = [filesystem_scan_exclude]
             for item in filesystem_scan_exclude:
                 item = os.path.normpath(item).replace('//', '/')
-                if os.path.exists(item):
-                    self.filesystem_scan_exclude_list.append(item)
+                if not os.path.exists(item):
+                    logger.info("Skipping missing filesystem_scan_exclude item: '%s'", item)
+                elif os.path.islink(item):
+                    logger.info("Skipping symlink filesystem_scan_exclude item: '%s'.  Please use non-symlink items", item)
                 else:
-                    logger.debug("Skipping missing filesystem_scan_exclude item: '%s'", item)
-            logger.info("Excluding specified filesystem item%s: %s", "s" if len(self.filesystem_scan_exclude_list) > 1 else "",
-                        self.filesystem_scan_exclude_list)
+                    self.filesystem_scan_exclude_list.append(item)
+            if self.filesystem_scan_exclude_list:
+                logger.info("Excluding specified filesystem item%s: %s", "s" if len(self.filesystem_scan_exclude_list) > 1 else "",
+                            self.filesystem_scan_exclude_list)
+            else:
+                logger.info("Unable to find the items specified for the filesystem_scan_exclude option.  Not excluding any filesystem items")
 
     @staticmethod
     def _parse_processes_scan_option(option_items):
@@ -504,7 +511,7 @@ class MalwareDetectionClient:
                 logger.info("Excluding specified process ID%s: %s", "s" if len(self.processes_scan_exclude_list) > 1 else "",
                             self.processes_scan_exclude_list)
             else:
-                logger.error("Unable to find the items specified for the processes_scan_exclude option.  Skipping ...")
+                logger.error("Unable to find the items specified for the processes_scan_exclude option.  Not excluding any processes.")
 
     def _parse_filesystem_scan_since_option(self):
         """
@@ -627,6 +634,11 @@ class MalwareDetectionClient:
             if '/redhat_access/' in self.insights_config.base_url:
                 # Satellite URLs have '/redhat_access/' in the base_url config option
                 self.rules_location = self.insights_config.base_url + '/malware-detection/v1/' + signatures_file
+            elif '.stage.redhat.com' in self.insights_config.base_url:
+                # For downloading rules in the stage environment, use the URL of base_url (after finding it)
+                base_url = urlparse(self.insights_config.base_url)
+                self.rules_location = base_url.netloc or base_url.scheme or base_url.path.split('/')[0] or 'cert.console.stage.redhat.com'
+                self.rules_location += '/api/malware-detection/v1/' + signatures_file
 
         # Make sure the rules_location starts with https://
         if not re.match('^https?://', self.rules_location):
@@ -650,16 +662,24 @@ class MalwareDetectionClient:
             log_rule_contents = True
 
         logger.debug("Downloading rules from: %s", self.rules_location)
-        try:
-            self.insights_config.cert_verify = True
-            conn = InsightsConnection(self.insights_config)
-            response = conn.get(self.rules_location, log_response_text=log_rule_contents)
-            if response.status_code != 200:
-                logger.error("%s %s: %s", response.status_code, response.reason, response.text)
-                exit(constants.sig_kill_bad)
-        except Exception as e:
-            logger.error("Unable to download rules from %s: %s", self.rules_location, str(e))
-            exit(constants.sig_kill_bad)
+        self.insights_config.cert_verify = True
+        conn = InsightsConnection(self.insights_config)
+
+        for attempt in range(1, self.insights_config.retries + 1):
+            try:
+                response = conn.get(self.rules_location, log_response_text=log_rule_contents)
+                if response.status_code != 200:
+                    raise Exception("%s %s: %s" % (response.status_code, response.reason, response.text))
+                break
+            except Exception as e:
+                if attempt < self.insights_config.retries:
+                    logger.debug("Unable to download rules from %s: %s", self.rules_location, str(e))
+                    retry_delay = attempt ** 2
+                    logger.debug("Trying again in %d seconds ...", retry_delay)
+                    time.sleep(retry_delay)
+                else:
+                    logger.error("Unable to download rules from %s: %s", self.rules_location, str(e))
+                    exit(constants.sig_kill_bad)
 
         self.temp_rules_file = NamedTemporaryFile(prefix='tmp_malware-detection-client_rules.', mode='wb', delete=True)
         self.temp_rules_file.write(response.content)
