@@ -143,6 +143,10 @@ plugins:
         - name: insights.combiners.services
           enabled: true
 
+    # needed for the 'teamdctl_state_dump' spec
+        - name: insights.parsers.nmcli.NmcliConnShow
+          enabled: true
+
     # needed for multiple Datasouce specs
         - name: insights.parsers.ps.PsAuxcww
           enabled: true
