@@ -287,7 +287,7 @@ class Grub1EFIConfig(Grub1Config):
         self._efi = True
 
 
-@parser(Specs.grub2_cfg, [IsRhel6, IsRhel7])
+@parser(Specs.grub2_cfg, [IsRhel6, IsRhel7, IsRhel8, IsRhel9])
 class Grub2Config(GrubConfig):
     """
     Parser for configuration for GRUB version 2.
@@ -347,7 +347,7 @@ class Grub2Config(GrubConfig):
         self.update({'menuentry': self.entries})
 
 
-@parser(Specs.grub2_efi_cfg, [IsRhel6, IsRhel7])
+@parser(Specs.grub2_efi_cfg, [IsRhel6, IsRhel7, IsRhel8])
 class Grub2EFIConfig(Grub2Config):
     """Parses grub2 configuration for EFI-based systems"""
     def __init__(self, *args, **kwargs):
