@@ -48,7 +48,8 @@ class PackageProvidesHttpd(CommandParser):
     def parse_content(self, content):
         deprecated(
             PackageProvidesHttpd,
-            'Please use the :class:`insights.parsers.package_provides.PackageProvidesCommand` instead.'
+            "Please use the :class:`insights.parsers.package_provides.PackageProvidesCommand` instead.",
+            "3.0.300"
         )
         if len(content) == 0:
             raise SkipException("Error: ", 'there is not httpd application running')
