@@ -7,6 +7,7 @@ class Specs(SpecSet):
     alternatives_display_python = RegistryPoint()
     amq_broker = RegistryPoint(multi_output=True)
     ansible_host = RegistryPoint()
+    auditctl_rules = RegistryPoint()
     auditctl_status = RegistryPoint()
     auditd_conf = RegistryPoint()
     audit_log = RegistryPoint(filterable=True)
@@ -322,22 +323,17 @@ class Specs(SpecSet):
     ls_docker_volumes = RegistryPoint()
     ls_edac_mc = RegistryPoint()
     ls_etc = RegistryPoint()
-    ls_etc_systemd = RegistryPoint()
     ls_ipa_idoverride_memberof = RegistryPoint()
     ls_lib_firmware = RegistryPoint()
     ls_ocp_cni_openshift_sdn = RegistryPoint()
     ls_origin_local_volumes_pods = RegistryPoint()
     ls_osroot = RegistryPoint()
-    ls_run_systemd = RegistryPoint()
     ls_R_var_lib_nova_instances = RegistryPoint()
     ls_sys_firmware = RegistryPoint()
+    ls_systemd_units = RegistryPoint()
     ls_usr_bin = RegistryPoint(filterable=True)
     ls_usr_lib64 = RegistryPoint(filterable=True)
-    ls_usr_lib_systemd = RegistryPoint()
-    ls_usr_local_lib_systemd = RegistryPoint()
-    ls_usr_local_share_systemd = RegistryPoint()
     ls_usr_sbin = RegistryPoint(filterable=True)
-    ls_usr_share_systemd = RegistryPoint()
     ls_var_cache_pulp = RegistryPoint()
     ls_var_lib_mongodb = RegistryPoint()
     ls_var_lib_nova_instances = RegistryPoint()
@@ -364,6 +360,7 @@ class Specs(SpecSet):
     lsvmbus = RegistryPoint()
     lvdisplay = RegistryPoint()
     lvm_conf = RegistryPoint(filterable=True)
+    lvm_system_devices = RegistryPoint()
     lvmconfig = RegistryPoint()
     lvs_noheadings = RegistryPoint()
     lvs_noheadings_all = RegistryPoint()
@@ -389,6 +386,8 @@ class Specs(SpecSet):
     modinfo_vmxnet3 = RegistryPoint()
     modinfo = RegistryPoint(multi_output=True)
     modinfo_all = RegistryPoint()
+    modinfo_filtered_modules = RegistryPoint()
+    modinfo_modules = RegistryPoint(filterable=True)
     modprobe = RegistryPoint(multi_output=True)
     mokutil_sbstate = RegistryPoint()
     mongod_conf = RegistryPoint(multi_output=True, filterable=True)
@@ -687,6 +686,8 @@ class Specs(SpecSet):
     sysctl_conf_initramfs = RegistryPoint(multi_output=True)
     sysctl_d_conf_etc = RegistryPoint(multi_output=True)
     sysctl_d_conf_usr = RegistryPoint(multi_output=True)
+    sys_fs_cgroup_memory_tasks_number = RegistryPoint()
+    system_user_dirs = RegistryPoint()
     systemctl_cat_dnsmasq_service = RegistryPoint()
     systemctl_cat_rpcbind_socket = RegistryPoint()
     systemctl_cinder_volume = RegistryPoint()
@@ -759,6 +760,7 @@ class Specs(SpecSet):
     vmware_tools_conf = RegistryPoint()
     vsftpd_conf = RegistryPoint(filterable=True)
     vsftpd = RegistryPoint()
+    wc_proc_1_mountinfo = RegistryPoint()
     x86_pti_enabled = RegistryPoint()
     x86_ibpb_enabled = RegistryPoint()
     x86_ibrs_enabled = RegistryPoint()
